'use strict';

var openai = require('@langchain/openai');
var pluginRagAiBackendRetrievalAugmenter = require('@alithya-oss/plugin-rag-ai-backend-retrieval-augmenter');

class RoadieOpenAiAugmenter extends pluginRagAiBackendRetrievalAugmenter.DefaultVectorAugmentationIndexer {
  constructor(config) {
    const embeddings = new openai.OpenAIEmbeddings({
      configuration: {
        baseURL: config.config.baseUrl,
        apiKey: config.config.openAiApiKey ?? config.config.apiKey
        // In Node.js defaults to process.env.OPENAI_API_KEY
      },
      openAIApiKey: config.config.openAiApiKey ?? config.config.apiKey,
      // In Node.js defaults to process.env.OPENAI_API_KEY
      batchSize: config.config.batchSize,
      // Default value if omitted is 512. Max is 2048
      modelName: config.config.modelName ? config.config.modelName : "text-embedding-3-small",
      dimensions: config.config.embeddingsDimensions
    });
    super({ ...config, embeddings });
  }
}

async function initializeOpenAiEmbeddings({
  logger,
  auth,
  vectorStore,
  catalogApi,
  discovery,
  config
}) {
  logger.info("Initializing Roadie OpenAI Embeddings");
  const openAiConfig = config.get("ai.embeddings.openai");
  const embeddingsOptions = config.getOptionalConfig("ai.embeddings");
  const augmentationOptions = {};
  if (embeddingsOptions) {
    augmentationOptions.chunkSize = embeddingsOptions.getOptionalNumber("chunkSize");
    augmentationOptions.chunkOverlap = embeddingsOptions.getOptionalNumber("chunkOverlap");
    augmentationOptions.concurrencyLimit = embeddingsOptions.getOptionalNumber("concurrencyLimit");
  }
  return new RoadieOpenAiAugmenter({
    vectorStore,
    catalogApi,
    discovery,
    augmentationOptions,
    logger: logger.child({ label: "roadie-openai-embeddings" }),
    auth,
    config: openAiConfig
  });
}

exports.initializeOpenAiEmbeddings = initializeOpenAiEmbeddings;
//# sourceMappingURL=index.cjs.js.map
